@@ -19,9 +19,9 @@
 
 """Provides the default implementation for flat review for Orca."""
 
-__id__        = "$Id: flat_review.py 4104 2008-08-15 18:41:16Z joanied $"
-__version__   = "$Revision: 4104 $"
-__date__      = "$Date: 2008-08-15 14:41:16 -0400 (Fri, 15 Aug 2008) $"
+__id__        = "$Id: flat_review.py 4191 2008-09-11 17:30:11Z joanied $"
+__version__   = "$Revision: 4191 $"
+__date__      = "$Date: 2008-09-11 13:30:11 -0400 (Thu, 11 Sep 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1159,12 +1159,21 @@ class Context:
             and accessible.childCount > 0:
             pass
         elif len(zones) == 0:
-            if accessible.name and len(accessible.name):
+            string = ""
+            if role == pyatspi.ROLE_COMBO_BOX:
+                try:
+                    selection = accessible[0].querySelection()
+                except:
+                    string = self.script.getDisplayedText(accessible[0])
+                else:
+                    item = selection.getSelectedChild(0)
+                    if item:
+                        string = item.name
+
+            if not string and accessible.name and len(accessible.name):
                 string = accessible.name
             elif accessible.description and len(accessible.description):
                 string = accessible.description
-            else:
-                string = ""
 
             if (string == "") \
                 and (role != pyatspi.ROLE_TABLE_CELL):
