@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2006 Sun Microsystems Inc.
+# Copyright 2006-2008 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -14,26 +14,18 @@
 #
 # You should have received a copy of the GNU Library General Public
 # License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# Free Software Foundation, Inc., Franklin Street, Fifth Floor,
+# Boston MA  02110-1301 USA.
 
 """Exposes a dictionary, pronunciation_dict, that maps words to what
 they sound like."""
 
-__id__        = "$Id: pronunciation_dict.py 2666 2007-08-17 15:09:57Z richb $"
-__version__   = "$Revision: 2666 $"
-__date__      = "$Date: 2007-08-17 11:09:57 -0400 (Fri, 17 Aug 2007) $"
-__copyright__ = "Copyright (c) 2006 Sun Microsystems Inc."
+__id__        = "$Id: pronunciation_dict.py 3882 2008-05-07 18:22:10Z richb $"
+__version__   = "$Revision: 3882 $"
+__date__      = "$Date: 2008-05-07 14:22:10 -0400 (Wed, 07 May 2008) $"
+__copyright__ = "Copyright (c) 2006-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
-from orca_i18n import _ # for gettext support
-
-# pronunciation_dict is a dictionary where the keys are words and the 
-# values represent word the pronunciation of that word (in other words, 
-# what the word sounds like).
-#
-pronunciation_dict = {}
-
 def getPronunciation(word, pronunciations=None):
     """Given a word, return a string that represents what this word
     sounds like.
@@ -51,9 +43,33 @@ def getPronunciation(word, pronunciations=None):
         word = word.encode("UTF-8")
 
     try:
+        lowerWord = word.decode("UTF-8").lower().encode("UTF-8")
         if pronunciations != None:
-            return pronunciations[word]
+            return pronunciations[lowerWord][1]
         else:
-            return pronunciation_dict[word]
+            return pronunciation_dict[lowerWord][1]
     except:
         return word
+
+def setPronunciation(word, replacementString, pronunciations=None):
+    """Given an actual word, and a replacement string, set a key/value
+    pair in a pronunciation dictionary.
+
+    Arguments:
+    - word: the word to be pronunced.
+    - replacementString: the replacement string to use instead.
+    - pronunciations: an optional dictionary used to set the pronunciation
+      into.
+    """
+
+    key = word.decode("UTF-8").lower().encode("UTF-8")
+    if pronunciations != None:
+        pronunciations[key] = [ word, replacementString ]
+    else:
+        pronunciation_dict[key] = [ word, replacementString ]
+
+# pronunciation_dict is a dictionary where the keys are words and the
+# values represent word the pronunciation of that word (in other words,
+# what the word sounds like).
+#
+pronunciation_dict = {}
