@@ -19,9 +19,9 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: script.py 3971 2008-06-11 00:54:46Z joanied $"
-__version__   = "$Revision: 3971 $"
-__date__      = "$Date: 2008-06-10 20:54:46 -0400 (Tue, 10 Jun 2008) $"
+__id__        = "$Id: script.py 4114 2008-08-20 00:19:40Z wwalker $"
+__version__   = "$Revision: 4114 $"
+__date__      = "$Date: 2008-08-19 20:19:40 -0400 (Tue, 19 Aug 2008) $"
 __copyright__ = "Copyright (c) 2005-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -1327,7 +1327,8 @@ class Script(default.Script):
             # so in this case.
             #
             if obj.getRole() == pyatspi.ROLE_FRAME and \
-                obj.name.endswith(_("Assistant")):
+                (obj.name.endswith(_("Assistant")) or \
+                obj.name.startswith(_("Assistant"))):
                 debug.println(self.debugLevel,
                               "evolution.locusOfFocusChanged - " \
                               + "setup assistant.")
@@ -1398,7 +1399,8 @@ class Script(default.Script):
                 # so in this case.
                 #
                 if obj.getRole() == pyatspi.ROLE_FRAME and \
-                    obj.name.endswith(_("Assistant")):
+                    (obj.name.endswith(_("Assistant")) or \
+                    obj.name.startswith(_("Assistant"))):
                     debug.println(self.debugLevel,
                                   "evolution.onStateChanged - " \
                                   + "setup assistant.")
