@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py 4176 2008-09-08 15:50:02Z wwalker $"
-__version__   = "$Revision: 4176 $"
-__date__      = "$Date: 2008-09-08 11:50:02 -0400 (Mon, 08 Sep 2008) $"
+__id__        = "$Id: settings.py 4190 2008-09-11 15:28:56Z wwalker $"
+__version__   = "$Revision: 4190 $"
+__date__      = "$Date: 2008-09-11 11:28:56 -0400 (Thu, 11 Sep 2008) $"
 __copyright__ = "Copyright (c) 2004-2008 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -592,6 +592,29 @@ GENERAL_KEYBOARD_LAYOUT_DESKTOP = 1
 GENERAL_KEYBOARD_LAYOUT_LAPTOP  = 2
 keyboardLayout                  = GENERAL_KEYBOARD_LAYOUT_DESKTOP
 
+# The red, green, blue values to use to outline the current item in
+# flat review mode. They are values between 0 and 65535 (0xFFFF), with
+# 65535 (0xFFFF) indicating full intensitiy
+#
+outlineColor = [ 0xFFFF, 0x0000, 0x0000 ]
+
+# Thickness in pixels of the outline around the the current item in flat 
+# review mode.
+#
+outlineThickness = 4
+
+# Margin between the object being outlined and the actual outline
+#
+outlineMargin = 1
+
+# The kind of outlining to do for flat review mode.
+#
+OUTLINE_NONE = 0
+OUTLINE_BOX = 1
+OUTLINE_LINE = 2
+OUTLINE_WEDGES = 3
+outlineStyle = OUTLINE_BOX
+
 # If True, speak blank lines.
 #
 speakBlankLines         = True
